import Map from 'ol/Map';
import colormap from 'colormap';

export default class MapProperties{

    private map: Map;
    private projection: string;
    public _completeDaterange: number[] = [1990, 2010];
    private temperatureBounds: {min: number, max: number} = {min: 0, max: 0}; //min/max of all station temperature, expect for colormap
    public _loadLayer2: boolean = false;
    public _anomalieRange1: number[] = [1960,1990];
    public _anomalieRange2: number[] = [1991,2018];
    public _stationDate: number = 2016;

    constructor(map:Map, projection: string){
        this.map = map;
        this.projection = projection;
    }

    public getMeanColorMap(outputformat: "rgba"|"hex"): any[]{
        return colormap({colormap:'temperature', nshades: 20, format: outputformat, alpha: 1});
    }

    public getAnomalieColorMap(outputformat: "rgba"|"hex"): any[]{
        return colormap({colormap:'hot', nshades: 20, format: outputformat, alpha: 1}).reverse();
    }

    public getTemperatureColorMap(): string[]{
        return colormap({colormap:'RdBu', nshades: 20, format: 'hex', alpha: 1});
    }

    public getTemperatureIcon(color: string): string{
        let icon = 'data:image/svg+xml;utf8,<svg xmlns="http://www.w3.org/2000/svg" height="24px" viewBox="0 0 24 24" width="24px" fill="%color%"><path d="M0 0h24v24H0z" fill="none"/><path d="M10 20v-6h4v6h5v-8h3L12 3 2 12h3v8z"   stroke="black"/></svg>';
        return icon.replace("%color%", color.replace("#", "%23"));
    }

    public setTemperatureBound(bound: {min: number, max: number}):void{
        this.temperatureBounds = bound;
    }

    public getTemperatureBound():{min: number, max: number}{
        return this.temperatureBounds;
    }

    public getZoomLevel():number{
        return this.map.getView().getZoom();
    }

    public getProjection(): string{
        return this.projection;
    }

    public getLoadLayer2():boolean{
        return this._loadLayer2;
    }
    public setLoadLayer2(value: boolean){
        this._loadLayer2 = value;
    }

    public set completeDaterange(range:number[]){
        this._completeDaterange = range;
    }
    public get completeDaterange(): number[]{
        return this._completeDaterange;
    }

    public set anomalieRange1(range:number[]){
        this._anomalieRange1 = range;
    }

    public get anomalieRange1():number[]{
        return this._anomalieRange1;
    }

    public set anomalieRange2(range:number[]){
        this._anomalieRange2 = range;
    }

    public get anomalieRange2():number[]{
        return this._anomalieRange2;
    }

    public set stationDate(value: number){
        this._stationDate = value;
    }

    public get stationDate():number{
        return this._stationDate;
    }


}